# TODO check that no license information gets lost
{ fetchurl, stdenv, python, go, cmake, vim, vimUtils, perl, ruby, unzip
, which, fetchgit, llvmPackages
, xkb_switch, rustracerd, fzf
, python3, boost, icu
, ycmd, makeWrapper, rake
, pythonPackages, python3Packages
, Cocoa ? null, git
}:

let

inherit (vimUtils.override {inherit vim;}) rtpPath addRtp buildVimPlugin
  buildVimPluginFrom2Nix vimHelpTags;
in

# TL;DR
# Add your plugin to ./vim-plugin-names
# Regenerate via `nix-shell -I nixpkgs=/path/to/your/local/fork -p vimPlugins.pluginnames2nix --command "vim-plugin-names-to-nix </dev/null"`
# Copy the generated expression(s) into this file.
# If plugin is complicated then make changes to ./vim2nix/additional-nix-code

# This attrs contains two sections:
# The first contains plugins added manually, the second contains plugins
# generated by call nix#ExportPluginsForNix.
# Documentation & usage see vim-utils.nix.
# attribute names should be the same as used by vim-pi to make dependency
# resolution work
rec {
  # This is not a plugin, it provides bin/vim-open-buffer-with-plugins-derivations
  # which recreates this the following derivations based on ./vim-plugin-names
  pluginnames2nix = vimUtils.pluginnames2Nix {
    name = "vim-plugin-names-to-nix";
    namefiles = [./vim-plugin-names];
  };

  # Section I
  vim-addon-vim2nix = vim2nix;

  vim2nix = buildVimPluginFrom2Nix { # use it to update plugins
    name = "vim2nix";
    src = ./vim2nix;
    dependencies = ["vim-addon-manager"];
  };


  # Section II
  # Update with vimUtils.vimPlugins.pluginnames2Nix command

  # aliasess
  "sourcemap.vim"     = sourcemap;
  Colour_Sampler_Pack = Colour-Sampler-Pack;
  YouCompleteMe       = youcompleteme;
  airline             = vim-airline;
  alternative         = a-vim; # backwards compat, added 2014-10-21
  calendar            = calendar-vim;
  coffee-script       = vim-coffee-script;
  coffeeScript        = coffee-script; # backwards compat, added 2014-10-18
  colors-solarized    = Solarized;
  colorsamplerpack    = Colour_Sampler_Pack;
  command_T           = command-t; # backwards compat, added 2014-10-18
  css_color_5056      = vim-css-color;
  ctrlp               = ctrlp-vim;
  easy-align          = vim-easy-align;
  easymotion          = vim-easymotion;
  eighties            = vim-eighties;
  ghc-mod-vim         = ghcmod;
  gist-vim            = Gist;
  gitgutter           = vim-gitgutter;
  gundo               = gundo-vim;
  Gundo               = gundo-vim; # backwards compat, added 2015-10-03
  haskellConceal      = haskellconceal; # backwards compat, added 2014-10-18
  haskellconceal      = vim-haskellconceal;
  haskellConcealPlus  = vim-haskellConcealPlus;
  hier                = vim-hier;
  hlint-refactor      = hlint-refactor-vim;
  hoogle              = Hoogle;
  ipython             = vim-ipython;
  latex-live-preview  = vim-latex-live-preview;
  multiple-cursors    = vim-multiple-cursors;
  necoGhc             = neco-ghc; # backwards compat, added 2014-10-18
  neocomplete         = neocomplete-vim;
  neosnippet          = neosnippet-vim;
  nerdcommenter       = The_NERD_Commenter;
  nerdtree            = The_NERD_tree;
  polyglot            = vim-polyglot;
  quickrun            = vim-quickrun;
  repeat              = vim-repeat;
  signature           = vim-signature;
  stylish-haskell     = vim-stylish-haskell;
  stylishHaskell      = stylish-haskell; # backwards compat, added 2014-10-18
  supertab            = Supertab;
  syntastic           = Syntastic;
  tabular             = Tabular;
  tagbar              = Tagbar;
  thumbnail           = thumbnail-vim;
  tmux-navigator      = vim-tmux-navigator;
  tmuxNavigator       = tmux-navigator; # backwards compat, added 2014-10-18
  tslime              = tslime-vim;
  unite               = unite-vim;
  vimproc             = vimproc-vim;
  vimshell            = vimshell-vim;
  watchdogs           = vim-watchdogs;
  webapi-vim          = WebAPI;
  wombat256           = wombat256-vim; # backwards compat, added 2015-7-8
  yankring            = YankRing;

  # do not auto-update this one, as the name clashes with vim-snippets
  vim-docbk-snippets = buildVimPluginFrom2Nix {
    name = "vim-docbk-snippets-2017-11-02";
    src = fetchgit {
      url = "https://github.com/jhradilek/vim-snippets";
      rev = "69cce66defdf131958f152ea7a7b26c21ca9d009";
      sha256 = "1363b2fmv69axrl2hm74dmx51cqd8k7rk116890qllnapzw1zjgc";
    };
    dependencies = [];
  };

  fzfWrapper = buildVimPluginFrom2Nix {
    name = fzf.name;
    src = fzf.src;
    dependencies = [];
  };

  # --- generated packages bellow this line ---

  CSApprox = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "CSApprox-2013-07-26";
    src = fetchgit {
      url = "git://github.com/godlygeek/csapprox";
      rev = "7981dac51d8b6776985aa08cb7b5ee98ea7f2ddd";
      sha256 = "08g4x6nnd6hkgm2daa5ihhz75pcdx3jzzv8rfjls80qajlhx5rf6";
    };
    dependencies = [];

  };

  CheckAttach = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "CheckAttach-2017-03-15";
    src = fetchgit {
      url = "git://github.com/chrisbra/CheckAttach";
      rev = "b583efd45e03902438a55299623390a0f9253513";
      sha256 = "0j1nx8ryrlixisd8z2d24k1xk2yrqk4i0ar8m4vq3jlr74309a34";
    };
    dependencies = [];

  };

  Gist = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Gist-2016-10-10";
    src = fetchgit {
      url = "git://github.com/mattn/gist-vim";
      rev = "f0d63579eab7548cf12f979dc52ef5a370ecbe63";
      sha256 = "06nix49j4inxy3rkcv32f4ka89g4crqwfqnrm3b76iwwky8m2p17";
    };
    dependencies = [];

  };

  Hoogle = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Hoogle-2017-11-04";
    src = fetchgit {
      url = "git://github.com/Twinside/vim-hoogle";
      rev = "14256fa4f482bb40f55311a6d8037103549c7844";
      sha256 = "1dhfy9s6q11cb424x595anj17sgsqywdyrcw3ynmk3949iiwaqhb";
    };
    dependencies = [];

  };

  Solarized = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Solarized-2011-05-09";
    src = fetchgit {
      url = "git://github.com/altercation/vim-colors-solarized";
      rev = "528a59f26d12278698bb946f8fb82a63711eec21";
      sha256 = "05d3lmd1shyagvr3jygqghxd3k8a4vp32723fvxdm57fdrlyzcm1";
    };
    dependencies = [];

  };

  Supertab = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Supertab-2017-06-20";
    src = fetchgit {
      url = "git://github.com/ervandew/supertab";
      rev = "22aac5c2cb6a8ebe906bf1495eb727717390e62e";
      sha256 = "1m70rx9ba2aqydfr9yxsrff61qyzmnda24qkgn666ypnsai7cfbn";
    };
    dependencies = [];

  };

  Syntastic = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Syntastic-2017-11-06";
    src = fetchgit {
      url = "git://github.com/scrooloose/syntastic";
      rev = "206b616c8e49f948d18231799c469aa3e6e2c29c";
      sha256 = "0q6k00x2gxd1lryqj80pqd0g9q1nmzz1fxacs81gxhx8c8hpxmcy";
    };
    dependencies = [];

  };

  Tabular = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Tabular-2016-05-04";
    src = fetchgit {
      url = "git://github.com/godlygeek/tabular";
      rev = "00e1e7fcdbc6d753e0bc8043e0d2546fa81bf367";
      sha256 = "185jpisk9hamcwb6aiavdzjdbbigzdra8f4mgs98r9cm9j448xkz";
    };
    dependencies = [];

  };

  Tagbar = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Tagbar-2017-10-19";
    src = fetchgit {
      url = "git://github.com/majutsushi/tagbar";
      rev = "dc155af2fdd20e081680d777bde558c56f8d55c3";
      sha256 = "0xicazayayp208qv7ln4shj41favj5a6aysvz29pwqy28svmg3xd";
    };
    dependencies = [];

  };

  The_NERD_Commenter = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "The_NERD_Commenter-2017-10-31";
    src = fetchgit {
      url = "git://github.com/scrooloose/nerdcommenter";
      rev = "63ba1a1123609c9bfb9f5d76debcd34afe429096";
      sha256 = "01aq0n5028kyvjzgb0yrzwnp0r3jiayahmbvkfakg3vw9hgapggr";
    };
    dependencies = [];

  };

  The_NERD_tree = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "The_NERD_tree-2017-11-02";
    src = fetchgit {
      url = "git://github.com/scrooloose/nerdtree";
      rev = "97433edd43f3a4a95c84389bcaafbe7a047cf756";
      sha256 = "04z45bs1a37mdck80bcqj3d0bp2zz5xyjkys0zv925mpq9rwx22s";
    };
    dependencies = [];

  };

  UltiSnips = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "UltiSnips-2017-06-30";
    src = fetchgit {
      url = "git://github.com/SirVer/ultisnips";
      rev = "423f264e753cec260b4f14455126e6db7ba429af";
      sha256 = "19g3k0nqzizv39rxwgkca9n2gsd19z2wwsmicr0zcgnf50nhkznh";
    };
    dependencies = [];

  };

  VimOutliner = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "VimOutliner-2017-08-02";
    src = fetchgit {
      url = "git://github.com/vimoutliner/vimoutliner";
      rev = "c13141d604959d84225c3a53dc4b0ef5ae8b2bfe";
      sha256 = "1bg45cnpvnk2k7r6l2n3sz0cw2lhrglphak10yp11yqf4q1rxl7x";
    };
    dependencies = [];

  };

  WebAPI = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "WebAPI-2017-04-26";
    src = fetchgit {
      url = "git://github.com/mattn/webapi-vim";
      rev = "e76f2da9a8f292a999a95ae688534f76c2dca9bd";
      sha256 = "02970g7blj478vid88gayba39rdcm9236nigkrijapyf5rd24zhh";
    };
    dependencies = [];

  };

  YankRing = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "YankRing";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=23487";
      name = "yankring_190.zip";
      sha256 = "0nnxpsfjp2p9jvs3y5ynnd5s56snz9927zdp9bgmay2jgxfmp0si";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=1234";
    };

    sourceRoot = ".";
  };

  clang_complete = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "clang_complete-2017-09-25";
    src = fetchgit {
      url = "git://github.com/Rip-Rip/clang_complete";
      rev = "fb8f4f25ab808bc83bc7c704f23171cb6b020737";
      sha256 = "0y80ds4l5gqqdm56ymkgsfpizpx96kzrr0ivx29q7ahd4ry847xa";
    };
    dependencies = [];
    # In addition to the arguments you pass to your compiler, you also need to
    # specify the path of the C++ std header (if you are using C++).
    # These usually implicitly set by cc-wrapper around clang (pkgs/build-support/cc-wrapper).
    # The linked ruby code shows generates the required '.clang_complete' for cmake based projects
    # https://gist.github.com/Mic92/135e83803ed29162817fce4098dec144
    # as an alternative you can execute the following command:
    # $ eval echo $(nix-instantiate --eval --expr 'with (import <nixpkgs>) {}; clang.default_cxx_stdlib_compile')
    preFixup = ''
      substituteInPlace "$out"/share/vim-plugins/clang_complete/plugin/clang_complete.vim \
        --replace "let g:clang_library_path = '' + "''" + ''" "let g:clang_library_path='${llvmPackages.clang.cc}/lib/libclang.so'"
    '';
  };

  commentary = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "commentary-2017-10-09";
    src = fetchgit {
      url = "git://github.com/tpope/vim-commentary";
      rev = "89f43af18692d22ed999c3097e449f12fdd8b299";
      sha256 = "0nqm4s00c607r58fz29n67r2z5p5r9qayl5y1chy8bcrl59m17a2";
    };
    dependencies = [];

  };

  ctrlp-cmatcher = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-cmatcher-2015-10-15";
    src = fetchgit {
      url = "git://github.com/JazzCore/ctrlp-cmatcher";
      rev = "6c36334f106b6fd981d23e724e9a618734cab43a";
      sha256 = "1573kd6xf3n8sxlz2j4zadai4rnc7k3s9c54648yfzickwn57d8q";
    };
    dependencies = [];
    buildInputs = [ python ];
    buildPhase = ''
      patchShebangs .
      ./install.sh
    '';
  };

  ctrlp-py-matcher = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-py-matcher-2017-11-01";
    src = fetchgit {
      url = "git://github.com/FelikZ/ctrlp-py-matcher";
      rev = "cf63fd546f1e80dd4db3db96afbeaad301d21f13";
      sha256 = "0hs829x3vxv12y78hz5g4a5qpw05xf42dk0hxxk3ind77mnl1ir1";
    };
    dependencies = [];

  };

  ctrlp-z = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-z-2015-10-17";
    src = fetchgit {
      url = "git://github.com/amiorin/ctrlp-z";
      rev = "d1a69ec623ce24b9a30fc8fe3cd468c322b03026";
      sha256 = "16nsj1g8lqmyizlb5ijwhf4dsmh0xv1kwqq6jxvhaf55vfga82yl";
    };
    dependencies = [];

  };

  extradite = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "extradite-2015-09-22";
    src = fetchgit {
      url = "git://github.com/int3/vim-extradite";
      rev = "52326f6d333cdbb9e9c6d6772af87f4f39c00526";
      sha256 = "0c89i0spvdm9vi65q15qcmsfmwa9rds2wmaq1kf6s7q7ywvs6w8i";
    };
    dependencies = [];

  };

  fugitive = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "fugitive-2017-10-21";
    src = fetchgit {
      url = "git://github.com/tpope/vim-fugitive";
      rev = "7c9b87a3c3ef4b53425aca4a27e11a7359caae9f";
      sha256 = "1kpgnn3pmy82kqy9vcvd1vi9jjmfj03p4606pvh42ky4y0m0qmms";
    };
    dependencies = [];

  };

  ghcmod = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ghcmod-2016-06-19";
    src = fetchgit {
      url = "git://github.com/eagletmt/ghcmod-vim";
      rev = "1d192d13d68ab59f9f46497a0909bf24a7b7dfff";
      sha256 = "0bzahgzagnf0a9zv86jhdf8nc3p0yfz9izv5n3lc8gc12cp47d0a";
    };
    dependencies = [];

  };

  vim-auto-save = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-auto-save-2017-03-10";
    src = fetchgit {
      url = "https://github.com/907th/vim-auto-save";
      rev = "a81dea26d2a62dbe1a0f89aba5834aee40a89512";
      sha256 = "16ljzp2rww9c13pl2ci2pqri1774qp3yhhh042n7vqxcwy80kjjc";
    };
    dependencies = [];

  };

  vim-autoformat = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-autoformat-2017-10-23";
    src = fetchgit {
      url = "https://github.com/Chiel92/vim-autoformat";
      rev = "c32b27cd4059770ff6f4639082b69e76ada948bd";
      sha256 = "1sy1bjrk560qww97538m883r8gkmfl114lbp68gdl0j48fdhmh78";
    };
    dependencies = [];

  };

  vim-nix = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-nix-2017-04-30";
    src = fetchgit {
      url = "https://github.com/LnL7/vim-nix";
      rev = "867488a04c2ddc47f0f235f37599a06472fea299";
      sha256 = "1mwc06z9q45cigyxd0r9qnfs4ph6lbcwx50rf5lmpavakcn3vqir";
    };
    dependencies = [];

  };

  tsuquyomi = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tsuquyomi-2017-11-01";
    src = fetchgit {
      url = "https://github.com/Quramy/tsuquyomi";
      rev = "fb5a5fd26bcca3c3a9fcde732b969e34c1ae89ea";
      sha256 = "0pg2w250fksnj168ygkdniryyr4asrr8y5fh2gq2hpyx6wpph7f8";
    };
    dependencies = [];

  };

  deoplete-nvim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-nvim-2017-11-04";
    src = fetchgit {
      url = "https://github.com/Shougo/deoplete.nvim";
      rev = "bea8e1c122d31ab6f2dd6f7d9a5b4545d08b2c4f";
      sha256 = "0y88h7w8d3h43yfjkawgn9inkyky5llrk8gmdfax5fqvgjgz4jg9";
    };
    dependencies = [];

  };

  Spacegray-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Spacegray-vim-2017-05-05";
    src = fetchgit {
      url = "https://github.com/ajh17/Spacegray.vim";
      rev = "95a5adbbbba7fb641af847d8666b8cad20431333";
      sha256 = "10p02n4arml1b4ah0bz754ifvkqnbms4j0wlgzqs5azb20y2kliv";
    };
    dependencies = [];

  };

  nerdtree-git-plugin = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "nerdtree-git-plugin-2017-03-12";
    src = fetchgit {
      url = "https://github.com/albfan/nerdtree-git-plugin";
      rev = "d79a5d5a1b3bc5fab3ba94db44a8b2e5a211d61d";
      sha256 = "0i77wijbr021zfv096ja15f5l52phvsd5gziqn1m3k60qkmb9gkj";
    };
    dependencies = [];

  };

  vim-closetag = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-closetag-2017-11-01";
    src = fetchgit {
      url = "https://github.com/alvan/vim-closetag";
      rev = "277e21d04c417112da6ecd3485373c6d3ff93b90";
      sha256 = "1wx9qqas0gd301pn9zabbl4b9v41i1hwbnd8fyy8kxxf0cbpdwaf";
    };
    dependencies = [];

  };

  flake8-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "flake8-vim-2017-02-17";
    src = fetchgit {
      url = "https://github.com/andviro/flake8-vim";
      rev = "01c4af4c68f33b2b3785314bfbf5b3d8d1451795";
      sha256 = "14rv0p1vx4njlplkc72gz7r8sy9vc6n8x9l00zc777x5zzrhgz3g";
    };
    dependencies = [];

  };

  vim-css-color = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-css-color-2017-11-03";
    src = fetchgit {
      url = "https://github.com/ap/vim-css-color";
      rev = "fcf5829daa7817994fb856dbaa905e6fd8beb50c";
      sha256 = "1a617ji11395zimqjgpcq2qciyjzq5ixm85vc8rkj8jda0qgm91c";
    };
    dependencies = [];

  };

  LanguageClient-neovim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "LanguageClient-neovim-2017-11-06";
    src = fetchgit {
      url = "https://github.com/autozimu/LanguageClient-neovim";
      rev = "a42cad5247417a1dbe7517748df14a76bd795fc1";
      sha256 = "1dk44xmxpq7yix0vpy8pzabk90l0cqxjm79w1zh8vqmpcp27z4jd";
    };
    dependencies = [];

  };

  clighter8 = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "clighter8-2017-09-30";
    src = fetchgit {
      url = "https://github.com/bbchung/clighter8";
      rev = "193512aaa722d1f3dfd3c07bd60942e59c753f25";
      sha256 = "1xl1ggkvwg8j6xhfgs1vcah9wksw2z03b1333iyfbgcjdxrdail6";
    };
    dependencies = [];
    buildInputs = [ makeWrapper ];
    preFixup = ''
      sed "/^let g:clighter8_libclang_path/s|')$|${llvmPackages.clang.cc}/lib/libclang.so')|" \
        -i "$out"/share/vim-plugins/clighter8/plugin/clighter8.vim
    '';
  };

  neomake = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neomake-2017-11-04";
    src = fetchgit {
      url = "https://github.com/benekastah/neomake";
      rev = "ef4e5be7315ffcb536b855974c91b1378beda62d";
      sha256 = "1xma1isbk7b3gccddfphvyxpi2sih6i1jgk69p8cig5rbggkrc4a";
    };
    dependencies = [];

  };

  vim-hdevtools = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hdevtools-2017-03-11";
    src = fetchgit {
      url = "https://github.com/bitc/vim-hdevtools";
      rev = "4ffdace7002915cb10d663a2c56386286c5b8e37";
      sha256 = "0s7qd72962sc56j8xzpzikjs9k5s89d5p0j541abl8zm0mavmyka";
    };
    dependencies = [];

  };

  vim-trailing-whitespace = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-trailing-whitespace-2017-09-22";
    src = fetchgit {
      url = "https://github.com/bronson/vim-trailing-whitespace";
      rev = "4c596548216b7c19971f8fc94e38ef1a2b55fee6";
      sha256 = "0f1cpnp1nxb4i5hgymjn2yn3k1jwkqmlgw1g02sq270lavp2dzs9";
    };
    dependencies = [];

  };

  vim-sort-motion = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-sort-motion-2017-10-03";
    src = fetchgit {
      url = "https://github.com/christoomey/vim-sort-motion";
      rev = "7384f20d829b4abde28ced40975f0beb319dce27";
      sha256 = "1x4hxa7dijb5g7vmrbgs2zi8aiqc759ljmh8qqwk6lafc016plnj";
    };
    dependencies = [];

  };

  vim-tmux-navigator = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-tmux-navigator-2017-07-07";
    src = fetchgit {
      url = "https://github.com/christoomey/vim-tmux-navigator";
      rev = "d724094e7128acd7375cc758008f1e1688130877";
      sha256 = "1n0n26lx056a0f8nmzbjpf8a48971g4d0fzv8xmq8yy505gbq9iw";
    };
    dependencies = [];

  };

  spacevim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "spacevim-2017-03-31";
    src = fetchgit {
      url = "https://github.com/ctjhoa/spacevim";
      rev = "f4cd52c1746021bb3278c6a085e8d07f1c1a9258";
      sha256 = "0y146z0w1cbqwzw84k479a5hxs1phg1s11fqfvszn8928fsm8c4d";
    };
    dependencies = [];

  };

  ctrlp-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-vim-2017-08-30";
    src = fetchgit {
      url = "https://github.com/ctrlpvim/ctrlp.vim";
      rev = "bde7a2950adaa82e894d7bdf69e3e7383e40d229";
      sha256 = "19q3cfs3rd3q1xfhyz55r1c3750nrjvwz7jxnhqqn751zgimnsyl";
    };
    dependencies = [];

  };

  agda-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "agda-vim-2017-07-18";
    src = fetchgit {
      url = "https://github.com/derekelkins/agda-vim";
      rev = "d82c5da78780e866e1afd8eecba1aa9c661c2aa8";
      sha256 = "1aq7wyi1an6znql814w3v30p96yzyd5xnypblzxvsi62jahysfwa";
    };
    dependencies = [];

  };

  vim-scala = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-scala-2017-04-29";
    src = fetchgit {
      url = "https://github.com/derekwyatt/vim-scala";
      rev = "e7640f26e56f0be344d60a6098e05d6928fd396d";
      sha256 = "17gyqzsjjsg48x760qpm31bi169bzq0g80nm88jjkjw75m9jbv2j";
    };
    dependencies = [];

  };

  vim-jade = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jade-2017-04-07";
    src = fetchgit {
      url = "https://github.com/digitaltoad/vim-jade";
      rev = "ddc5592f8c36bf4bd915c16b38b8c76292c2b975";
      sha256 = "069pha18g1nlzg44k742vjxm4zwjd1qjzhfllkr35qaiflvjm84y";
    };
    dependencies = [];

  };

  pony-vim-syntax = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "pony-vim-syntax-2017-09-26";
    src = fetchgit {
      url = "https://github.com/dleonard0/pony-vim-syntax";
      rev = "caa34b3d7a15d9bfbfbb2f5944c85eb1eddcfafc";
      sha256 = "0r2lv99hkm95dv8wy9rkrkcwz5wkmwggfwi5vakgw497l3a9jskr";
    };
    dependencies = [];

  };

  vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-2017-05-24";
    src = fetchgit {
      url = "https://github.com/dracula/vim";
      rev = "6a5bf34193927c70b6c21dcbe1c130d2ab0951d6";
      sha256 = "1mmqrc52k133ddpxcs0mxjph4n4b856r5wbs17bgcpk95cfbspb1";
    };
    dependencies = [];

  };

  xptemplate = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "xptemplate-2017-04-18";
    src = fetchgit {
      url = "https://github.com/drmingdrmer/xptemplate";
      rev = "52d84e361e9da53c4309b0d96a1ab667c67b7f07";
      sha256 = "195r5p4cyiip64zmgcih56c59gwm0irgid6cdrqc2y747gyxmf7m";
    };
    dependencies = [];

  };

  neco-ghc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neco-ghc-2017-08-17";
    src = fetchgit {
      url = "https://github.com/eagletmt/neco-ghc";
      rev = "faa033c05e6a6470d3d780e3931b4c9c72042009";
      sha256 = "01l5n4x94sb6bhjhjx2sibs8gm3zla7hb6szdfgbdmdf7jlzazak";
    };
    dependencies = [];

  };

  editorconfig-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "editorconfig-vim-2017-10-14";
    src = fetchgit {
      url = "https://github.com/editorconfig/editorconfig-vim";
      rev = "0abb0634a8bf3c760a283e9e7475594b83869a46";
      sha256 = "1wazl37ivn9nhsy296g1ncvvwc78930lbp8arhwavr52mzpfji21";
    };
    dependencies = [];

  };

  acp = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "acp-2013-02-05";
    src = fetchgit {
      url = "https://github.com/eikenb/acp";
      rev = "5c627cec37d0d3b1670cb250d84e176e8b0c644e";
      sha256 = "0h7s4nvxin7m2caka7g1hhlxj1bbiwsvw8s2lqwlh7nq43v23ghg";
    };
    dependencies = [];

  };

  vim-elixir = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-elixir-2017-10-20";
    src = fetchgit {
      url = "https://github.com/elixir-lang/vim-elixir";
      rev = "3066d5fb5e1c694e607b2bb5d8277266ca524262";
      sha256 = "1j5sic3rssh2kaj73lv4m5sck3irn1jzgkpdr5qw7qi0gyfgpg81";
    };
    dependencies = [];

  };

  elm-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "elm-vim-2017-07-09";
    src = fetchgit {
      url = "https://github.com/elmcast/elm-vim";
      rev = "ae5315396cd0f3958750f10a5f3ad9d34d33f40d";
      sha256 = "0a85l0mcxgha4s5c9lzdv9y2c1ff942y9a5sfjihz6sph21c77xp";
    };
    dependencies = [];

  };

  vim-localvimrc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-localvimrc-2017-07-06";
    src = fetchgit {
      url = "https://github.com/embear/vim-localvimrc";
      rev = "48c01c214ea0312e8045aaa1a28b30850e98a194";
      sha256 = "158ajdg3n8j0cxk2ry8rmnpfvnzmznhl573v8ddw6xni58b7bg4d";
    };
    dependencies = [];

  };

  vim-haskellConcealPlus = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-haskellConcealPlus-2016-05-13";
    src = fetchgit {
      url = "https://github.com/enomsg/vim-haskellConcealPlus";
      rev = "81dfb51ff8e471fb1f30659a10daaf1bdd65fb03";
      sha256 = "0vm76gxw62lkyxccrlnn8sblfl3d51svwfra9wfixq4h51jdggyr";
    };
    dependencies = [];

  };

  ensime-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ensime-vim-2017-08-27";
    src = fetchgit {
      url = "https://github.com/ensime/ensime-vim";
      rev = "d992b971a84afdfb2d99896d8aed537030e09a80";
      sha256 = "1rhrq3zplvpyli1ymqjmhq91p61ixpjz1v5xf68nvq4ax50nl45z";
    };
    dependencies = ["vimproc" "vimshell" "self" "forms"];
    pythonDependencies = with pythonPackages; [ sexpdata websocket_client ];
  };

  YUNOcommit-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "YUNOcommit-vim-2014-11-26";
    src = fetchgit {
      url = "https://github.com/esneider/YUNOcommit.vim";
      rev = "981082055a73ef076d7e27477874d2303153a448";
      sha256 = "0mjc7fn405vcx1n7vadl98p5wgm6jxrlbdbkqgjq8f1m1ir81zab";
    };
    dependencies = [];

  };

  vim-go = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-go-2017-11-05";
    src = fetchgit {
      url = "https://github.com/fatih/vim-go";
      rev = "c0d209cce7f0eb0af250d2471ae9495a8bf1f19e";
      sha256 = "1ci8nhsnda4wrpqi0knara1dqjjba6bccbqiw6va8d9mzsr12ivn";
    };
    dependencies = [];

  };

  vim-colorschemes = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-colorschemes-2017-08-22";
    src = fetchgit {
      url = "https://github.com/flazz/vim-colorschemes";
      rev = "eab315701f4627967fd62582eefc4e37a3745786";
      sha256 = "12jfqfs6lqd6jijxrdx3k76bzxrh9517zwczb73qjaqbg286fh5k";
    };
    dependencies = [];

  };

  floobits-neovim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "floobits-neovim-2017-08-02";
    src = fetchgit {
      url = "https://github.com/floobits/floobits-neovim";
      rev = "9ccd5a8d5d28261b9686717d61a32b756f38f189";
      sha256 = "02njg49qz9bfzggpn7z5c7w1wa1k5hxly66904wizl601fa6c664";
    };
    dependencies = [];

  };

  psc-ide-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "psc-ide-vim-2017-10-24";
    src = fetchgit {
      url = "https://github.com/frigoeu/psc-ide-vim";
      rev = "23bf302de91181d409fb988ce372ab703b119bc5";
      sha256 = "1yjnc6173zdxbcbszrv7184rk5jax6d187c1klsm8b6lx4j1jv4d";
    };
    dependencies = [];

  };

  vim-jsonnet = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jsonnet-2017-04-06";
    src = fetchgit {
      url = "https://github.com/google/vim-jsonnet";
      rev = "2637e273713322befc476760809d46500e6088f3";
      sha256 = "0fxmqasznb3ra49r4j3fmksik7narnd3b6j1j4najp4l61x27ip2";
    };
    dependencies = [];

  };

  vim-jsdoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jsdoc-2017-02-11";
    src = fetchgit {
      url = "https://github.com/heavenshell/vim-jsdoc";
      rev = "cd8f084c3b4bd198620d45a007cee6b009b57b35";
      sha256 = "0a2d9jwxjws8l7y89yn7xl07r5yh7r7987a8hfalvz12qmdmff1j";
    };
    dependencies = [];

  };

  vim-leader-guide = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-leader-guide-2017-03-18";
    src = fetchgit {
      url = "https://github.com/hecal3/vim-leader-guide";
      rev = "6ac8c663e65c9c0ded70417b84f66ee59457893e";
      sha256 = "1hqha3ig40ls15bnb10xpbl91swn0gxqnhmz5frkvvdzj4wq55fw";
    };
    dependencies = [];

  };

  idris-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "idris-vim-2017-08-02";
    src = fetchgit {
      url = "https://github.com/idris-hackers/idris-vim";
      rev = "7f1363b65e14a8918d17f98b7f16de8f44f6bd00";
      sha256 = "07ws5c1yfv4kp1yl4fa634l9w162pp784zg12r2953xzwwmgwr83";
    };
    dependencies = [];

  };

  calendar-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "calendar-vim-2017-07-08";
    src = fetchgit {
      url = "https://github.com/itchyny/calendar.vim";
      rev = "6d6be26b2ad1870658525e2a42046429c845516c";
      sha256 = "0g4k7vn3r8y0ss0nl6apxgpkdi7ixi87a9g5xr66n70lxyn7m9pz";
    };
    dependencies = [];

  };

  lightline-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "lightline-vim-2017-11-05";
    src = fetchgit {
      url = "https://github.com/itchyny/lightline.vim";
      rev = "73f125dcf24db4baabe9be76d02de63be22dbd44";
      sha256 = "1aj0sn3fs78993nk8qfvyfbbny3586fnmsvkqkg7n9j2gd7dfn93";
    };
    dependencies = [];

  };

  thumbnail-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "thumbnail-vim-2017-04-24";
    src = fetchgit {
      url = "https://github.com/itchyny/thumbnail.vim";
      rev = "71cb5d48e59fc77149c1d1036ecd9e39f0b46a00";
      sha256 = "0b25n28ri6n5rrvgfynv8rm5pzzxpnrnj1l3647pf2fjxd2z2rv5";
    };
    dependencies = [];

  };

  vim-ipython = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-ipython-2015-06-23";
    src = fetchgit {
      url = "https://github.com/ivanov/vim-ipython";
      rev = "42499f094b805b90b683afa5009cee99abd0bb75";
      sha256 = "10wpfvfs8yv1bvzra4d5zy5glp62gbalpayxx7mkalhr2ccppy3x";
    };
    dependencies = [];

  };

  vim-hier = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hier-2011-08-27";
    src = fetchgit {
      url = "https://github.com/jceb/vim-hier";
      rev = "0b8c365263551a67404ebd7e528c55e17c1d3de7";
      sha256 = "118pd9sx1bl9vfr89xrf536hfx4l162a43a1qpwpkqxzb9a3ca7n";
    };
    dependencies = [];
    buildInputs = [ vim ];
  };

  vim-orgmode = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-orgmode-2017-04-19";
    src = fetchgit {
      url = "https://github.com/jceb/vim-orgmode";
      rev = "8a5cb51fbb8d89b0151833a6deb654929818a964";
      sha256 = "0siqzwblads3n69chqsifpgglcda2iz2k40q76llf78fw5ylqd16";
    };
    dependencies = [];

  };

  vim-buffergator = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-buffergator-2017-02-05";
    src = fetchgit {
      url = "https://github.com/jeetsukumaran/vim-buffergator";
      rev = "04dfbc0c78b0a29b340a99d0ff36ecf8f16e017d";
      sha256 = "1z13qqmvzismz7f6ss2pk956adnqh14df8qrlzk9rgplknm4w6k7";
    };
    dependencies = [];

  };

  tslime-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tslime-vim-2016-06-14";
    src = fetchgit {
      url = "https://github.com/jgdavey/tslime.vim";
      rev = "c980c76bbfc9a523fcf1edf08580d0d3a486e8f2";
      sha256 = "0gifyxwlspfnkni886adwn9kc0dckanjk0097y8pwxh7qbwfydf1";
    };
    dependencies = [];

  };

  vim-docbk = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-docbk-2015-04-01";
    src = fetchgit {
      url = "https://github.com/jhradilek/vim-docbk";
      rev = "6ac0346ce96dbefe982b9e765a81c072997f2e9e";
      sha256 = "1jnx39m152hf9j620ygagaydg6h8m8gxkr1fmxj6kgqf71jr0n9d";
    };
    dependencies = [];

  };

  auto-pairs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "auto-pairs-2017-07-03";
    src = fetchgit {
      url = "https://github.com/jiangmiao/auto-pairs";
      rev = "f0019fc6423e7ce7bbd01d196a7e027077687fda";
      sha256 = "1kzrdq3adwxwm3fw65g05ww9405lwqi368win5kayamyj9i0z7r6";
    };
    dependencies = [];

  };

  vim-nerdtree-tabs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-nerdtree-tabs-2017-07-04";
    src = fetchgit {
      url = "https://github.com/jistr/vim-nerdtree-tabs";
      rev = "47bbe5afc26f701f08d31b2bbdb660f117367ded";
      sha256 = "0a1gqdvmpa4gylnb7sxs6zr89i60fl16p477200x18hgh2zd2v02";
    };
    dependencies = [];

  };

  zenburn = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "zenburn-2015-09-18";
    src = fetchgit {
      url = "https://github.com/jnurmine/zenburn";
      rev = "f7847fb1531b91e2b4bb4aed5db3146f07765179";
      sha256 = "1las12jznf25dkxrjk3s9l70c6wnpjisngmvi83bhw5gvx4c7mq5";
    };
    dependencies = [];

  };

  vim-colorstepper = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-colorstepper-2016-01-28";
    src = fetchgit {
      url = "https://github.com/jonbri/vim-colorstepper";
      rev = "f23ba0d995d41508a2dc9471cf31d3d01a4b5f05";
      sha256 = "05ykxn0gmh8liz0zv5hb8df1ajggxp88izq3825m0yb3ma3k1jqs";
    };
    dependencies = [];

  };

  vim-xdebug = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-xdebug-2012-08-15";
    src = fetchgit {
      url = "https://github.com/joonty/vim-xdebug";
      rev = "a4980fa65f7f159780593ee37c178281691ba2c4";
      sha256 = "1qh18r0sm4gh95sjbi2hnflvxdl4gk00jyy3n7z4i1gnx9ihxjqw";
    };
    dependencies = [];
    postInstall = false;
  };

  fzf-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "fzf-vim-2017-11-02";
    src = fetchgit {
      url = "https://github.com/junegunn/fzf.vim";
      rev = "5c6cee878a71ed27b137aafa7993624a357c0b82";
      sha256 = "07wavw8j170siysjvpmm2znv6c1q72w1m0cgs908v9pr1fh1bghj";
    };
    dependencies = [];

  };

  limelight-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "limelight-vim-2016-06-24";
    src = fetchgit {
      url = "https://github.com/junegunn/limelight.vim";
      rev = "106fb5749d227a0de72e36068ed72798c6fd48e6";
      sha256 = "0fp4yp50n5v5zx3a7afh9wip4nwcfhmdgdzwpnl79jvild1z9fgh";
    };
    dependencies = [];

  };

  vim-peekaboo = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-peekaboo-2017-03-20";
    src = fetchgit {
      url = "https://github.com/junegunn/vim-peekaboo";
      rev = "a7c940b15b008afdcea096d3fc4d25e3e431eb49";
      sha256 = "1rc4hr6vwj2mmrgz8lifxf9rvcw1rb5dahq649yn8ccw03x8zn6m";
    };
    dependencies = [];

  };

  vim-eighties = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-eighties-2016-12-15";
    src = fetchgit {
      url = "https://github.com/justincampbell/vim-eighties";
      rev = "1a6ea42ead1e31524ec94cfefb6afc1d8dacd170";
      sha256 = "1yh1kny28c7f5qm52y7xd5aj4mycksfb0x1zvcb37c73ycdxc1v2";
    };
    dependencies = [];

  };

  latex-box = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "latex-box-2015-06-01";
    src = fetchgit {
      url = "https://github.com/latex-box-team/latex-box";
      rev = "3c2901e12cb78bfb2be58ba4c62a488612550fe1";
      sha256 = "1z4mdy47cpwcdhvy8mr72vhlybxn1y59yd3ixf6ids1bzpkrd7zl";
    };
    dependencies = [];

  };

  typescript-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "typescript-vim-2017-10-24";
    src = fetchgit {
      url = "https://github.com/leafgarland/typescript-vim";
      rev = "fbd0e9e508535f7d89778f7280dc76505348dcc6";
      sha256 = "1psxdkr35m1x6lpsrn2v482sn9n4pysw1i0j9nr1g7r4nh1058fk";
    };
    dependencies = [];

  };

  vim-jinja = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jinja-2016-11-16";
    src = fetchgit {
      url = "https://github.com/lepture/vim-jinja";
      rev = "8d330a7aaf0763d080dc82204b4aaba6ac0605c6";
      sha256 = "1n62ga02rcj7jjgzvwr46pckj59dc1zqahjgampjcwdd8vf4mg3q";
    };
    dependencies = [];

  };

  vimtex = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimtex-2017-11-01";
    src = fetchgit {
      url = "https://github.com/lervag/vimtex";
      rev = "b56537a229d74fab815090e8e4b4ae873121e69c";
      sha256 = "1d94i19bkgqay7n5108majla2bx3nw5s230a2nw761v327bp65wd";
    };
    dependencies = [];

  };

  vim-easymotion = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easymotion-2017-10-20";
    src = fetchgit {
      url = "https://github.com/lokaltog/vim-easymotion";
      rev = "342549e7a1e5b07a030803e0e4b6f0415aa51275";
      sha256 = "1glv4s95v8xxj47n0jzjxd0pxphnnpgzyd384d2bh0ql1xgf320v";
    };
    dependencies = [];

  };

  vim-lawrencium = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-lawrencium-2017-01-10";
    src = fetchgit {
      url = "https://github.com/ludovicchabant/vim-lawrencium";
      rev = "88077183e1f5a9a1f741aeab7a1374cfed9e917f";
      sha256 = "0z31v93wjycq4lqvbl1jzxi7i5i1vl919m4dyyzphybcqrjjpnab";
    };
    dependencies = [];

  };

  rainbow = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rainbow-2017-04-21";
    src = fetchgit {
      url = "https://github.com/luochen1990/rainbow";
      rev = "1c45e0f81324641b23d4c21edda4eabeacba031b";
      sha256 = "143bkawg4sy1vbizfwb6p9alizyr80sr6incxrz179l9dp9r8frf";
    };
    dependencies = [];

  };

  vim-xkbswitch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-xkbswitch-2017-03-27";
    src = fetchgit {
      url = "https://github.com/lyokha/vim-xkbswitch";
      rev = "a85ebddb9038e6b05138c48868a319a9e13d1868";
      sha256 = "0v0wckkvsj3pd3a5lj35dqwlvgr1kfz0x6rpnx28mzrcg05p19fr";
    };
    dependencies = [];
    patchPhase = ''
      substituteInPlace plugin/xkbswitch.vim \
              --replace /usr/local/lib/libxkbswitch.so ${xkb_switch}/lib/libxkbswitch.so
    '';
    buildInputs = [ xkb_switch ];
  };

  vim-highlightedyank = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-highlightedyank-2017-10-03";
    src = fetchgit {
      url = "https://github.com/machakann/vim-highlightedyank";
      rev = "5fb7d0f2cb9e25397b1a6e1a5345584a6975b724";
      sha256 = "19jzaiv4iqgqvbwj6r5m6037qfm5nhk6jcwciyfacispdycmpkp7";
    };
    dependencies = [];

  };

  Jenkinsfile-vim-syntax = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Jenkinsfile-vim-syntax-2017-08-29";
    src = fetchgit {
      url = "https://github.com/martinda/Jenkinsfile-vim-syntax";
      rev = "e3d2e19ad1c8f79872380901c0392c2671757831";
      sha256 = "18bfyjsxgqg562n8kkcnyd05pp17ipap7ray9az92fapzhw5q4x9";
    };
    dependencies = [];

  };

  forms = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "forms-2012-11-28";
    src = fetchgit {
      url = "https://github.com/megaannum/forms";
      rev = "b601e03fe0a3b8a43766231f4a6217e4492b4f75";
      sha256 = "19kp1i5c6jmnpbsap9giayqbzlv7vh02mp4mjvicqj9n0nfyay74";
    };
    dependencies = ["self"];

  };

  self = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "self-2014-05-28";
    src = fetchgit {
      url = "https://github.com/megaannum/self";
      rev = "2ed666b547eddee6ae1fcc63babca4ba0b66a59f";
      sha256 = "1gcwn6i5i3msg7hrlzsnv1bs6pm4jz9cff8ppaz2xdj8xv9qy6fn";
    };
    dependencies = [];

  };

  robotframework-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "robotframework-vim-2017-04-14";
    src = fetchgit {
      url = "https://github.com/mfukar/robotframework-vim";
      rev = "75d5b371a4da2a090a2872d55bd0dead013f334e";
      sha256 = "091ac5rq6f1a7j2q3dy9rc00vckv21m4wd29ijj63jannr02v5ad";
    };
    dependencies = [];

  };

  vim-startify = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-startify-2017-11-02";
    src = fetchgit {
      url = "https://github.com/mhinz/vim-startify";
      rev = "22ccf5861397dd2365756c24ce1952736632cd8c";
      sha256 = "1np32vz56hz19hd6zpz154dim2mzw3x1lx1vyhkkyda8rd9w4rmb";
    };
    dependencies = [];

  };

  vim-indent-object = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-indent-object-2017-03-23";
    src = fetchgit {
      url = "https://github.com/michaeljsmith/vim-indent-object";
      rev = "41d700f14b3decccdde421fbfe49e95a084a2f89";
      sha256 = "12mi4n5abfxx7xjl46aw400acgrjf1fxjgzak763l874y0whf5v2";
    };
    dependencies = [];

  };

  ack-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ack-vim-2017-11-05";
    src = fetchgit {
      url = "https://github.com/mileszs/ack.vim";
      rev = "6e04746a63dd2453601ae36c83d53fe2021a45f4";
      sha256 = "0453ghmaaqwv6z8a3sncd3jxs9j050sp9ymiw2aqpc1a28kdlrv8";
    };
    dependencies = [];

  };

  vim-yapf = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-yapf-2017-03-21";
    src = fetchgit {
      url = "https://github.com/mindriot101/vim-yapf";
      rev = "324380d77c9cf8e46e22b2e4391702273a53f563";
      sha256 = "0vsd53k5k8absc60qka8nlj2ij6k4zgff2a65ixc7vqcmawxr3nw";
    };
    dependencies = [];
    buildPhase = ''
      substituteInPlace ftplugin/python_yapf.vim \
        --replace '"yapf"' '"${pythonPackages.yapf}/bin/yapf"'
    '';
  };

  lushtags = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "lushtags-2017-04-19";
    src = fetchgit {
      url = "https://github.com/mkasa/lushtags";
      rev = "fd7fa5a0162d9aa159559880d5ba4731e180eeaf";
      sha256 = "1si5n07k4r8kji4whglav9q59ksv6bi5v58xbpc2l5bavlk8kn6n";
    };
    dependencies = [];

  };

  hlint-refactor-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "hlint-refactor-vim-2015-12-05";
    src = fetchgit {
      url = "https://github.com/mpickering/hlint-refactor-vim";
      rev = "fffb044ecef854a82c5c2efda252e09044ba03e0";
      sha256 = "0z8d31arfy9aidg1dwj5msnnx799d9r7njkgh51z695w6ayxn6p8";
    };
    dependencies = [];

  };

  vim-indent-guides = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-indent-guides-2017-07-03";
    src = fetchgit {
      url = "https://github.com/nathanaelkane/vim-indent-guides";
      rev = "b40687195c01caf40f62d20093296590b48e3a75";
      sha256 = "17hc3bdb707lkg0kyac2czjjijdrzarnh6sr78s9rqpwrj3fj4i4";
    };
    dependencies = [];

  };

  vim-stylish-haskell = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-stylish-haskell-2015-05-10";
    src = fetchgit {
      url = "https://github.com/nbouscal/vim-stylish-haskell";
      rev = "c664376ba814de3f87cb7641f90b2c6a9dd53671";
      sha256 = "1xm5ark2mwphznv3xsyzgcldnr52i5jzk1pfqdh0080j07aama8j";
    };
    dependencies = [];

  };

  haskell-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "haskell-vim-2017-10-16";
    src = fetchgit {
      url = "https://github.com/neovimhaskell/haskell-vim";
      rev = "d877d5cd5f2f5747fa835d4b639499187fa4ae9e";
      sha256 = "16iihz0jy61s5dyzzf5dbvd6ii1zna98pckqkjlpxcqqx636sm5c";
    };
    dependencies = [];

  };

  cpsm = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "cpsm-2017-10-30";
    src = fetchgit {
      url = "https://github.com/nixprime/cpsm";
      rev = "3744240ca48f98eea064f3cbc1a62b3f25f44030";
      sha256 = "0x5jac7x85bqdh38vggi1fvxjw2z29b2227n471f3cxy8arvylrw";
    };
    dependencies = [];
    buildInputs = [
      python3
      stdenv
      cmake
      boost
      icu
    ];
    buildPhase = ''
      patchShebangs .
      export PY3=ON
      ./install.sh
    '';
  };

  shabadou-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "shabadou-vim-2016-07-19";
    src = fetchgit {
      url = "https://github.com/osyo-manga/shabadou.vim";
      rev = "7d4bfed1ea8985ae125df3d1403cc19e252443e1";
      sha256 = "1kvik1yf7yjg9jdmdw38yhkksxg0n3nry02banwik7wgjnpvg870";
    };
    dependencies = [];

  };

  vim-watchdogs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-watchdogs-2017-10-23";
    src = fetchgit {
      url = "https://github.com/osyo-manga/vim-watchdogs";
      rev = "4ba5e8f2d456d36ef4e660580245c648a6f106ff";
      sha256 = "1736m48yp41p2kwn6n0jmkzvxi84mf4llk1zw38n0v8npzcc2lnp";
    };
    dependencies = [];

  };

  vim-markdown = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-markdown-2017-05-10";
    src = fetchgit {
      url = "https://github.com/plasticboy/vim-markdown";
      rev = "3fcde7215e22913f004c2836fd46ff61746be6db";
      sha256 = "0ymbs7235zi5hwyzc0vaikb3n6jwj6xarmgjj4lpf4wbsa1212yy";
    };
    dependencies = [];

  };

  python-mode = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "python-mode-2017-07-04";
    src = fetchgit {
      url = "https://github.com/python-mode/python-mode";
      rev = "d2dead6ce9d900b26dbf1a06c52969f4194eda64";
      sha256 = "1iq26a2l9maapz3433pwywmqla4wf7jass7s7bh32h10m2fh88a0";
    };
    dependencies = [];

  };

  vim-racer = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-racer-2017-10-15";
    src = fetchgit {
      url = "https://github.com/racer-rust/vim-racer";
      rev = "da725d38a6f0dd223771018c05e62a33c4a92f09";
      sha256 = "16m9iw6x6wr26ilm72vwjsm9p346hbjd6md62mqk6ranln8rdirp";
    };
    dependencies = [];

  };

  purescript-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "purescript-vim-2017-10-19";
    src = fetchgit {
      url = "https://github.com/raichoo/purescript-vim";
      rev = "ece34d9782a075761f31854a33eccd932eb2cf57";
      sha256 = "0x6hpibmhgw5aqq25rcpvgz2a60jh7i8x23gigakmmrxv51cjcrj";
    };
    dependencies = [];

  };

  vim-grammarous = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-grammarous-2017-08-25";
    src = fetchgit {
      url = "https://github.com/rhysd/vim-grammarous";
      rev = "51ef5190813c0d9d8aaebd5191f183cff767f805";
      sha256 = "1mm8hd39q2sl4hi83c4zvrl27a8djr1pv35ch0pivg84ad9p7qq5";
    };
    dependencies = [];

  };

  vim-puppet = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-puppet-2017-08-25";
    src = fetchgit {
      url = "https://github.com/rodjek/vim-puppet";
      rev = "0d8ddd0dc3b7c908a82a6f16fa61aade766cc7e3";
      sha256 = "1jgn9vahyn80zz0wfzx9abamsahh9wrrq1nf9qghljm4si3fq766";
    };
    dependencies = [];

  };

  nvim-cm-racer = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "nvim-cm-racer-2017-07-27";
    src = fetchgit {
      url = "https://github.com/roxma/nvim-cm-racer";
      rev = "2a8a4a49fa58c5dac9e0bed9511f6928930cacd2";
      sha256 = "1yljxwypgn91084yyicbc2qprn31ld7s4drvnddzczyhzq5m2gpx";
    };
    dependencies = [];

  };

  nvim-completion-manager = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "nvim-completion-manager-2017-10-26";
    src = fetchgit {
      url = "https://github.com/roxma/nvim-completion-manager";
      rev = "a56d17bcfc107bed851c9a36f1a6fc8e93c04acd";
      sha256 = "18zd7sigp93057lw4mx9jfqrp1l31kwhh8df5kfimbyh75xpj469";
    };
    dependencies = [];

  };

  rust-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rust-vim-2017-09-20";
    src = fetchgit {
      url = "https://github.com/rust-lang/rust.vim";
      rev = "b6d88adcf9867aa69f4d20d45d49bb54979842a4";
      sha256 = "0n0hiqlv3amnzn69wyyq6z3r8zr0gcg86hw6flk7z39cxjhjv3vr";
    };
    dependencies = [];

  };

  vim-devicons = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-devicons-2017-10-13";
    src = fetchgit {
      url = "https://github.com/ryanoasis/vim-devicons";
      rev = "a3e50225a8d544c9eff9c53c5405269a1b2b29f8";
      sha256 = "0glnwqnaw28g41zd9c3wvcsk6fmiphlwiq80lskbyn1pxfb3h14m";
    };
    dependencies = [];

  };

  neoformat = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neoformat-2017-11-01";
    src = fetchgit {
      url = "https://github.com/sbdchd/neoformat";
      rev = "0e2cfe93a14639b9e26373593a4a61b30e5e96ff";
      sha256 = "1nzc8yjpbimbg0sn3cmn4jkb1f91lk0iqg4c38czlzlvbfb2xasq";
    };
    dependencies = [];

  };

  deoplete-rust = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-rust-2017-07-18";
    src = fetchgit {
      url = "https://github.com/sebastianmarkow/deoplete-rust";
      rev = "0a86e502113910c33448b337c4d50cabea120d25";
      sha256 = "0wsck83jns40ny3740vwjhc8g5bh6zl71hkirbjxy6n4xgixa54h";
    };
    dependencies = [];

  };

  vim-polyglot = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-polyglot-2017-10-27";
    src = fetchgit {
      url = "https://github.com/sheerun/vim-polyglot";
      rev = "a61ab44810a0cb78223a179d78eff16d2e0b8bf6";
      sha256 = "0q3h46blqv963c4m636hr48j9ka1x2qv4naja7q2rr4f2pndhd23";
    };
    dependencies = [];

  };

  neco-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neco-vim-2017-10-01";
    src = fetchgit {
      url = "https://github.com/shougo/neco-vim";
      rev = "f5397c5e800d65a58c56d8f1b1b92686b05f4ca9";
      sha256 = "0yb7ja6qgrazszk4i01cwjj00j9vd43zs2r11b08iy8n10jnzr73";
    };
    dependencies = [];

  };

  neocomplete-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neocomplete-vim-2017-10-22";
    src = fetchgit {
      url = "https://github.com/shougo/neocomplete.vim";
      rev = "46791e7692e07384a089d125c5c536246698d04c";
      sha256 = "1iqd6fqlkm8bvibsapcvqqmyklzjad2l0c745lppdgdb959v016a";
    };
    dependencies = [];

  };

  neosnippet-snippets = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neosnippet-snippets-2017-09-26";
    src = fetchgit {
      url = "https://github.com/shougo/neosnippet-snippets";
      rev = "8dbb78599984140c50418d3dd23d0de4c8f13e74";
      sha256 = "1hs4xvr9x03ccrcczhly4qlvr5bfxfvdk3ir4821mlg1gsgclkwh";
    };
    dependencies = [];

  };

  neosnippet-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neosnippet-vim-2017-10-01";
    src = fetchgit {
      url = "https://github.com/shougo/neosnippet.vim";
      rev = "ddd01d0ee3d965d9a30051f2e12b14234c83b3ae";
      sha256 = "0475ilqyg0ppk276awvva2iaslm993l364vqcxqrl31x7ir2qa7f";
    };
    dependencies = [];

  };

  unite-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "unite-vim-2017-10-22";
    src = fetchgit {
      url = "https://github.com/shougo/unite.vim";
      rev = "c5c69d5d94e61a67d61730d04c82763196f63b10";
      sha256 = "1zn23x1bx40z0anl42v8ac8dv0c7f29rd1vwdqsmwdrkyxlyi1n1";
    };
    dependencies = [];

  };

  vimproc-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimproc-vim-2017-07-22";
    src = fetchgit {
      url = "https://github.com/shougo/vimproc.vim";
      rev = "03a38f283ca9e15784e8fea84e8afc5d633b9639";
      sha256 = "0ypffp724f3qp0mryxmmmi1ci0bnz34nnr7yi3c893pd9mpkrjjr";
    };
    dependencies = [];
    buildInputs = [ which ];

    buildPhase = ''
      substituteInPlace autoload/vimproc.vim \
        --replace vimproc_mac.so vimproc_unix.so \
        --replace vimproc_linux64.so vimproc_unix.so \
        --replace vimproc_linux32.so vimproc_unix.so
      make -f make_unix.mak
    '';
  };

  vimshell-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimshell-vim-2016-12-14";
    src = fetchgit {
      url = "https://github.com/shougo/vimshell.vim";
      rev = "d0c5bef010237855b4de25863bc54895effe5d7a";
      sha256 = "13szswi1n04w66c4h701y47xblrba8ysxjwvmnfxb0pyd1x3gzgz";
    };
    dependencies = [ "vimproc-vim" ];
  };

  gundo-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "gundo-vim-2017-05-09";
    src = fetchgit {
      url = "https://github.com/sjl/gundo.vim";
      rev = "46c443ee9d5854320eb965a1fdee781ba83a070e";
      sha256 = "0adk7agzmbfv342zw6lc8jad6yjs1wap4c0ca98s0qm2bs0r1hl2";
    };
    dependencies = [];

  };

  alchemist-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "alchemist-vim-2017-10-31";
    src = fetchgit {
      url = "https://github.com/slashmili/alchemist.vim";
      rev = "15e6439439997a02fddb65fd3db51c1eb62207c0";
      sha256 = "03hvkj6957hcmlfqpzlddhm675ljqb7ka5r3j95ykl80npmqrnml";
    };
    dependencies = [];

  };

  vim-hardtime = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hardtime-2017-03-31";
    src = fetchgit {
      url = "https://github.com/takac/vim-hardtime";
      rev = "d9128568afa62947b7ac8f12c22d88e3de526a6b";
      sha256 = "097wzfh4n4fnsq2gx4hbmyr731ciky8qcai5aiyh2baybvwshmr5";
    };
    dependencies = [];

  };

  vim-expand-region = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-expand-region-2013-08-19";
    src = fetchgit {
      url = "https://github.com/terryma/vim-expand-region";
      rev = "966513543de0ddc2d673b5528a056269e7917276";
      sha256 = "0l30wjlk4vxr16f1njnvf8aw9yg9p9jisvcxbcg3znsq5q8ix6zv";
    };
    dependencies = [];

  };

  vimpreviewpandoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimpreviewpandoc-2016-03-07";
    src = fetchgit {
      url = "https://github.com/tex/vimpreviewpandoc";
      rev = "b109d41ad6478df5ec7f1311950c6efca66f36e4";
      sha256 = "1gx326xarjs3qjygpkrknncad90crjqfx8v6pir4r7k1hl7dfxc4";
    };
    dependencies = [];

  };

  vim-quickrun = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-quickrun-2017-08-14";
    src = fetchgit {
      url = "https://github.com/thinca/vim-quickrun";
      rev = "13e60587a503620bd7d0dd1b822c29e18350e461";
      sha256 = "185pqahvpmag01vzr2xh68vnfz6fybpd3qlpr2qdq8712x11apwi";
    };
    dependencies = [];

  };

  molokai = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "molokai-2015-11-11";
    src = fetchgit {
      url = "https://github.com/tomasr/molokai";
      rev = "c67bdfcdb31415aa0ade7f8c003261700a885476";
      sha256 = "1piszjr5kyw43ac1f0jh9z88g824xknshrkchbys9qxlz7pd831s";
    };
    dependencies = [];

  };

  vim-dispatch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-dispatch-2017-10-10";
    src = fetchgit {
      url = "https://github.com/tpope/vim-dispatch";
      rev = "be7b194f47bdee6baa4460ccd030b860ada548dd";
      sha256 = "0lxhk6y1lf625i8hnsl44wzh8mfxi2h1hswrmisbmm2dbmyy84hd";
    };
    dependencies = [];

  };

  vim-eunuch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-eunuch-2017-06-08";
    src = fetchgit {
      url = "https://github.com/tpope/vim-eunuch";
      rev = "b536b887072ff3cc382842ce9f675ec222302f4f";
      sha256 = "0vp037kb12mawy186cm384m5hl0p051rihhm1jr2qck0vwaps58p";
    };
    dependencies = [];

  };

  vim-repeat = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-repeat-2017-04-21";
    src = fetchgit {
      url = "https://github.com/tpope/vim-repeat";
      rev = "070ee903245999b2b79f7386631ffd29ce9b8e9f";
      sha256 = "1grsaaar2ng1049gc3r8wbbp5imp31z1lcg399vhh3k36y34q213";
    };
    dependencies = [];

  };

  vim-speeddating = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-speeddating-2017-05-24";
    src = fetchgit {
      url = "https://github.com/tpope/vim-speeddating";
      rev = "a418667791f03694065948342f2d6c5cca8d0f32";
      sha256 = "1wm33izawazh0dy70zjk6rkg30yrlldba5r1gypnr4barps702gw";
    };
    dependencies = [];

  };

  hasksyn = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "hasksyn-2014-09-03";
    src = fetchgit {
      url = "https://github.com/travitch/hasksyn";
      rev = "c434040bf13a17ca20a551223021b3ace7e453b9";
      sha256 = "09998lnfcshqis5m062wlag6y476imq9jday9gp4ayjjl1cp3cwx";
    };
    dependencies = [];

  };

  vim-haskellconceal = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-haskellconceal-2017-06-15";
    src = fetchgit {
      url = "https://github.com/twinside/vim-haskellconceal";
      rev = "802f82a5afee56e9e1251e6f756104a3bd114234";
      sha256 = "1kh6853hi4rgl4z1xs8kz9l1q9w7lh0r42y2m0rabfpr6yh3091r";
    };
    dependencies = [];

  };

  youcompleteme = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "youcompleteme-2017-10-27";
    src = fetchgit {
      url = "https://github.com/valloric/youcompleteme";
      rev = "bade99f5e9c5ba2f848cffb2d1a905e85d3ddb05";
      sha256 = "0rf9gd4asq9bddhp3c6qvvjcm6zpiadjhvslknkqh1i9aq01kj7a";
    };
    dependencies = [];
    buildPhase = ''
      substituteInPlace plugin/youcompleteme.vim \
        --replace "'ycm_path_to_python_interpreter', '''" \
                  "'ycm_path_to_python_interpreter', '${python}/bin/python'"

      rm -r third_party/ycmd
      ln -s ${ycmd}/lib/ycmd third_party
    '';

    meta = {
      description = "Fastest non utf-8 aware word and C completion engine for Vim";
      homepage = https://github.com/Valloric/YouCompleteMe;
      license = stdenv.lib.licenses.gpl3;
      maintainers = with stdenv.lib.maintainers; [marcweber jagajaga];
      platforms = stdenv.lib.platforms.unix;
    };
  };

  vim-airline-themes = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-airline-themes-2017-10-29";
    src = fetchgit {
      url = "https://github.com/vim-airline/vim-airline-themes";
      rev = "26f67b926553555e505ac60e992c97ab5fdfc83f";
      sha256 = "0gzhi7l0cwzd66mzkrs6pgbzm9vqkkyhv4cwblywh5dkqqa9q71x";
    };
    dependencies = [];

  };

  vim-pandoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-2017-11-04";
    src = fetchgit {
      url = "https://github.com/vim-pandoc/vim-pandoc";
      rev = "e9a24376c17817632951088838a3c3bdc1c5da30";
      sha256 = "17mmvsvdzmx9xqhxiryvv8l67m52bd4xl9lyrg0h9vk8s58cy0ig";
    };
    dependencies = [];

  };

  vim-pandoc-after = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-after-2015-06-01";
    src = fetchgit {
      url = "https://github.com/vim-pandoc/vim-pandoc-after";
      rev = "4377665e5c98f29ea838deb3b942200b8dd096ef";
      sha256 = "1379g174pvsaw1wdv1n18gby84sv59rsamfcgq9bqd4kg54g6h3j";
    };
    dependencies = [];

  };

  vim-pandoc-syntax = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-syntax-2017-04-13";
    src = fetchgit {
      url = "https://github.com/vim-pandoc/vim-pandoc-syntax";
      rev = "56e8e41ef863a0a7d33d85c3c0c895aa6e9e62d3";
      sha256 = "19ll4zrw5yd0frgsbi7pg9b68lmy4bfiwbnwgzii7inifrqsykfw";
    };
    dependencies = [];

  };

  Colour-Sampler-Pack = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Colour-Sampler-Pack-2012-11-29";
    src = fetchgit {
      url = "https://github.com/vim-scripts/Colour-Sampler-Pack";
      rev = "05cded87b2ef29aaa9e930230bb88e23abff4441";
      sha256 = "03v2r18sfgs0xbgy9p56pxfdg0lsk6m7wyr5hw63wm1nzpwiipg3";
    };
    dependencies = [];

  };

  Rename = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Rename-2011-08-30";
    src = fetchgit {
      url = "https://github.com/vim-scripts/Rename";
      rev = "b240f28d2ede65fa77cd99fe045efe79202f7a34";
      sha256 = "1d1myg4zyc281zcc1ba9idbgcgxndb4a0jwqr4yqxhhzdgszw46r";
    };
    dependencies = [];

  };

  ReplaceWithRegister = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ReplaceWithRegister-2014-10-30";
    src = fetchgit {
      url = "https://github.com/vim-scripts/ReplaceWithRegister";
      rev = "832efc23111d19591d495dc72286de2fb0b09345";
      sha256 = "0mb0sx85j1k59b1zz95r4vkq4kxlb4krhncq70mq7fxrs5bnhq8g";
    };
    dependencies = [];

  };

  a-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "a-vim-2010-11-06";
    src = fetchgit {
      url = "https://github.com/vim-scripts/a.vim";
      rev = "2cbe946206ec622d9d8cf2c99317f204c4d41885";
      sha256 = "0h62v9z5bh9xmaq22pqdb3z79i84a5rknqm68mjpy7nq7s3q42fa";
    };
    dependencies = [];

  };

  align = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "align-2012-08-07";
    src = fetchgit {
      url = "https://github.com/vim-scripts/align";
      rev = "787662fe90cd057942bc5b682fd70c87e1a9dd77";
      sha256 = "0acacr572kfh7jvavbw61q5pkwrpi1albgancma063rpax1pddgp";
    };
    dependencies = [];

  };

  argtextobj-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "argtextobj-vim-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/argtextobj.vim";
      rev = "f3fbe427f7b4ec436416a5816d714dc917dc530b";
      sha256 = "1l4jh5hdmky1qj5z26jpnk49a6djjcvzyyr6pknrrgb8rzkiln48";
    };
    dependencies = [];

  };

  changeColorScheme-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "changeColorScheme-vim-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/changeColorScheme.vim";
      rev = "b041d49f828629d72f2232531a230d1ec5de2405";
      sha256 = "0pybhsg9k9252d4ifdc4gsar8lkmfzbvs6xkzqq1m6f35l9wqk09";
    };
    dependencies = [];

  };

  random-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "random-vim-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/random.vim";
      rev = "b2d85eb24a38074eab37a5acf2a295e1f2ad8989";
      sha256 = "1lzy2cq4jcrsqyxlnbnd0y6j4mabm09bi7q22lf6vinqlb84w7sp";
    };
    dependencies = [];

  };

  tabmerge = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tabmerge-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/tabmerge";
      rev = "074e5f06f26e7108a0570071a0f938a821768c06";
      sha256 = "0prkyza1n49cdaslcr57w8zv15vw78mlqbzib2xipmawzjq02idq";
    };
    dependencies = [];

  };

  wombat256-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "wombat256-vim-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/wombat256.vim";
      rev = "8734ba45dcf5e38c4d2686b35c94f9fcb30427e2";
      sha256 = "01fdvfwdfqn5xi88lfanb4lb6jmn1ma6wq6d9jj2x7qamdbpvsrg";
    };
    dependencies = [];

  };

  ale = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ale-2017-11-05";
    src = fetchgit {
      url = "https://github.com/w0rp/ale";
      rev = "fa7d041c26aa6616c13a62274a7fc8458f6096dd";
      sha256 = "13h4pcahnfm0b5f7zbyfg7w2ailv8id58v59sp7h2qk3cx7zwb9k";
    };
    dependencies = [];

  };

  vim-wakatime = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-wakatime-2017-11-05";
    src = fetchgit {
      url = "https://github.com/wakatime/vim-wakatime";
      rev = "23e92a5701bad21f3604b3ab129546aef51a9b80";
      sha256 = "0hmpjrqy1w4qimpfg1l6sj5h9zbyz7lfzs3mjv1d3d2sp413warh";
    };
    dependencies = [];
    buildInputs = [ python ];
  };

  command-t = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "command-t-2017-09-29";
    src = fetchgit {
      url = "https://github.com/wincent/command-t";
      rev = "c5882de56f0ca3ce8e891c434f192519aca5c7bb";
      sha256 = "0dbghh7fwy49zyjick7840dkbybqchjw2sg9c6p0kmp5w3j46b92";
    };
    dependencies = [];
    buildInputs = [ ruby rake ];
    buildPhase = ''
      rake make
      rm ruby/command-t/ext/command-t/*.o
    '';
  };

  vim-easytags = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easytags-2015-07-01";
    src = fetchgit {
      url = "https://github.com/xolox/vim-easytags";
      rev = "72a8753b5d0a951e547c51b13633f680a95b5483";
      sha256 = "0i8ha1fa5d860b1mi0xp8kwsgb0b9vbzcg1bldzv6s5xd9yyi12i";
    };
    dependencies = ["vim-misc"];

  };

  vim-misc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-misc-2015-05-21";
    src = fetchgit {
      url = "https://github.com/xolox/vim-misc";
      rev = "3e6b8fb6f03f13434543ce1f5d24f6a5d3f34f0b";
      sha256 = "0rd9788dyfc58py50xbiaz5j7nphyvf3rpp3yal7yq2dhf0awwfi";
    };
    dependencies = [];

  };

  nim-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "nim-vim-2017-10-31";
    src = fetchgit {
      url = "https://github.com/zah/nim.vim";
      rev = "ae63bd21211b68d21b176ad5ea0cc4fc8f90eda5";
      sha256 = "1i5yxddwlcr3d2bzv5g9jz1z2lg7xnd6i038ph02rvllngcfsv00";
    };
    dependencies = [];

  };

  deoplete-go = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-go-2017-09-08";
    src = fetchgit {
      url = "https://github.com/zchee/deoplete-go";
      rev = "9330737f365bcf430a9481561f24271ea2ab120b";
      sha256 = "1j8i2ahpwa0v9mjwl45a6bdqdsksyh0fpwpl96jgylq58d2g5gzb";
    };
    dependencies = [];
    buildInputs = [ python3 ];
    buildPhase = ''
      pushd ./rplugin/python3/deoplete/ujson
      python3 setup.py build --build-base=$PWD/build --build-lib=$PWD/build
      popd
      find ./rplugin/ -name "ujson*.so" -exec mv -v {} ./rplugin/python3/ \;
    '';
  };

  deoplete-jedi = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-jedi-2017-10-24";
    src = fetchgit {
      url = "https://github.com/zchee/deoplete-jedi";
      rev = "436624ce43d1424d4efef42e0990ac5fd19b5029";
      sha256 = "0phgjf6v90lwcbx2lks461ny6v4x5ypcs2cidg51w2jav2xvlqrq";
    };
    dependencies = [];

  };

  zig-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "zig-vim-2017-10-17";
    src = fetchgit {
      url = "https://github.com/zig-lang/zig.vim";
      rev = "6059db59f61b517f5d65303b61f03324e01fdc2f";
      sha256 = "0w3pa63s0r6h6w1iqmc444qrsc99xcccwapd6nyh3gb72z228d7z";
    };
    dependencies = [];

  };

  goyo = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "goyo-2017-06-01";
    src = fetchgit {
      url = "git://github.com/junegunn/goyo.vim";
      rev = "5b8bd0378758c1d9550d8429bef24b3d6d78b592";
      sha256 = "0jh2gyf6v1vl12hygzwylzsj1ivx7r6xrd75k2wfsy91b2pm9srj";
    };
    dependencies = [];

  };

  gruvbox = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "gruvbox-2017-10-01";
    src = fetchgit {
      url = "git://github.com/morhetz/gruvbox";
      rev = "16504d394e145e0372d2491e02769d241350399a";
      sha256 = "0yhas9lnsn9lfld37lvm5msmmkj6c7d8ajgarazc5rykbl8bw8rg";
    };
    dependencies = [];

  };

  matchit-zip = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "matchit-zip";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=8196";
      name = "matchit.zip";
      sha256 = "1bbm8j1bhb70kagwdimwy9vcvlrz9ax5bk2a7wrmn4cy87f9xj4l";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=39";
    };

    unpackPhase = ''
      (
       sourceRoot=d
       mkdir $sourceRoot; cd $sourceRoot;
       unzip $src
      )
    '';
  };

  pathogen = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "pathogen-2017-08-04";
    src = fetchgit {
      url = "git://github.com/tpope/vim-pathogen";
      rev = "e7857bed4e0705f91f781dbe99706f07d08d104b";
      sha256 = "15s08q1chrdywj7fdiwzygxywg4cpcbvk5r1r8zvw6d82kyhadw1";
    };
    dependencies = [];

  };

  quickfixstatus = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "quickfixstatus-2011-09-02";
    src = fetchgit {
      url = "git://github.com/dannyob/quickfixstatus";
      rev = "fd3875b914fc51bbefefa8c4995588c088163053";
      sha256 = "16vxhvyxq51y7wnx0c1fmdi2yb6kfr1pxijq65gxj8qwvbak2s3v";
    };
    dependencies = [];

  };

  rainbow_parentheses = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rainbow_parentheses-2013-03-04";
    src = fetchgit {
      url = "git://github.com/kien/rainbow_parentheses.vim";
      rev = "eb8baa5428bde10ecc1cb14eed1d6e16f5f24695";
      sha256 = "1qw84imlhq4654mxazj7j3sp5g1j3yjxi496i08iix06dm15m5s7";
    };
    dependencies = [];

  };

  sensible = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sensible-2017-05-09";
    src = fetchgit {
      url = "git://github.com/tpope/vim-sensible";
      rev = "49ee364222dc2a5a00dddf89fd61880e3e39d46a";
      sha256 = "0x9zn547hzzxjzplr2rkzhydh2y0a4fdkrwmdvw2yp203msyhcjx";
    };
    dependencies = [];

  };

  sleuth = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sleuth-2017-10-24";
    src = fetchgit {
      url = "git://github.com/tpope/vim-sleuth";
      rev = "d56a4302358359ddf9845252addf637a5e6bd6d5";
      sha256 = "1klp2lqsql90v156kih0mnm0j957pc4r0zy5y6srww2q3wkkjgr2";
    };
    dependencies = [];

  };

  snipmate = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "snipmate-2017-04-20";
    src = fetchgit {
      url = "git://github.com/garbas/vim-snipmate";
      rev = "a9802f2351910f64b70fb10b63651e6ff6b8125e";
      sha256 = "1l7sc6lf66pkiy18aq9s3wk1dmvvvsy1063cc0bxich9xa8m34bj";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  sourcemap = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sourcemap-2012-09-19";
    src = fetchgit {
      url = "git://github.com/chikatoike/sourcemap.vim";
      rev = "0dd82d40faea2fdb0771067f46c01deb41610ba1";
      sha256 = "1gcgnynallz420911fdfm0ccbv3zs78p69nnh2ls1r4vlfp7g350";
    };
    dependencies = [];

  };

  surround = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "surround-2016-06-01";
    src = fetchgit {
      url = "git://github.com/tpope/vim-surround";
      rev = "e49d6c2459e0f5569ff2d533b4df995dd7f98313";
      sha256 = "1v0q2f1n8ngbja3wpjvqp2jh89pb5ij731qmm18k41nhgz6hhm46";
    };
    dependencies = [];

  };

  table-mode = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "table-mode-2017-10-26";
    src = fetchgit {
      url = "git://github.com/dhruvasagar/vim-table-mode";
      rev = "40fe641708c58476c3a1b9aeafb68dd888d4920b";
      sha256 = "1rb2jq81965gpziqxlljr2bqjyfbikqa9ncxaaak3x61prn4z084";
    };
    dependencies = [];

  };

  taglist = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "taglist";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=19574";
      name = "taglist_46.zip";
      sha256 = "18cbv462vwg7vip2p99qlahm99hswav96cj4ki227kyi05q2lkjj";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=273";
    };

    setSourceRoot = ''
      export sourceRoot=taglist
      mkdir taglist
      mv doc taglist
      mv plugin taglist
    '';
  };

  tlib = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tlib-2017-08-13";
    src = fetchgit {
      url = "git://github.com/tomtom/tlib_vim";
      rev = "c96db6151fde9d06a8fed71b7df05c6dbb3f14fe";
      sha256 = "1dhvf1v2mkmq8aifwq57ylm7nnk3zz3hna33q2gj6p7v70vay7v8";
    };
    dependencies = [];

  };

  undotree = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "undotree-2017-10-26";
    src = fetchgit {
      url = "git://github.com/mbbill/undotree";
      rev = "cdbb9022b8972d3e156b8d60af33bf795625b058";
      sha256 = "0y62hp8k2kbrq0jhxj850f706rqjv2dkd7dxhz458mrsdk60f253";
    };
    dependencies = [];

  };

  vim-addon-actions = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-actions-2017-09-23";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-actions";
      rev = "7f48bea57fd9dfb06498422bc1cbe9f7553efa6e";
      sha256 = "0q9w2x49zd3a43cm4ikgpwrqiz0k9a6pss0zrvskaxhh6mifpxpg";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-async = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-async-2017-03-20";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-async";
      rev = "eca316a4480f68c2cb62128f3187dc7b2002afde";
      sha256 = "1lk8ma51dd0syi73vq5r4qk9cpy6cq3llizvh94hmxblfjpvrs7q";
    };
    dependencies = ["vim-addon-signs"];

  };

  vim-addon-background-cmd = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-background-cmd-2015-12-11";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-background-cmd";
      rev = "abf2abf339652d2bc79da81f9d131edfe2755f5a";
      sha256 = "0csy68x686l3x5ancidxb5b6prg9k7ikybqzq3klx0gs5rmksfy4";
    };
    dependencies = ["vim-addon-mw-utils"];

  };

  vim-addon-commenting = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-commenting-2013-06-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-commenting";
      rev = "b7cf748ac1c9bf555cbd347589e3b7196030d20b";
      sha256 = "0alak8h33vada2ckb0v06y82qlib5mhyc2yswlv1rqh8ypzhq3mc";
    };
    dependencies = [];

  };

  vim-addon-completion = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-completion-2015-02-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-completion";
      rev = "021c449a5ce1ce4ac0af5955e05b0279c1cc0e75";
      sha256 = "1ld059y2qwlc5bdfjm2p314s1qh31lxs54g944pw49r46s5nlslr";
    };
    dependencies = ["tlib"];

  };

  vim-addon-errorformats = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-errorformats-2014-11-05";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-errorformats";
      rev = "dcbb203ad5f56e47e75fdee35bc92e2ba69e1d28";
      sha256 = "159zqm69fxbxcv3b2y99g57bf20qrzsijcvb5rzy2njxah3049m1";
    };
    dependencies = [];

  };

  vim-addon-goto-thing-at-cursor = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-goto-thing-at-cursor-2012-01-11";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-goto-thing-at-cursor";
      rev = "f052e094bdb351829bf72ae3435af9042e09a6e4";
      sha256 = "1ksm2b0j80zn8sz2y227bpcx4jsv76lwgr2gpgy2drlyqhn2vlv0";
    };
    dependencies = ["tlib"];

  };

  vim-addon-local-vimrc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-local-vimrc-2015-03-19";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-local-vimrc";
      rev = "6a27f95b35befa70cd0d049329cd0920566c764b";
      sha256 = "0n8lwl1gyak149p7jpgm0qbmfj8hcg8hirx3dxdhizw0yc47ws7h";
    };
    dependencies = [];

  };

  vim-addon-manager = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-manager-2017-05-07";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-manager";
      rev = "2434225ae48e608c2b6ac86c8da1c62209da746f";
      sha256 = "1fczkd05gir994614qmgscx131isr71bn0rwa6n3vgdbnhasz6bb";
    };
    dependencies = [];
    buildInputs = stdenv.lib.optional stdenv.isDarwin Cocoa;
  };

  vim-addon-mru = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-mru-2013-08-08";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-mru";
      rev = "e41e39bd9d1bf78ccfd8d5e1bc05ae5e1026c2bb";
      sha256 = "0q6rxr9nrp63kidr3m3c2z5sda4g813pzshg0scxkjr8dxwhzdqm";
    };
    dependencies = ["vim-addon-other" "vim-addon-mw-utils"];

  };

  vim-addon-mw-utils = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-mw-utils-2012-11-05";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-mw-utils";
      rev = "0c5612fa31ee434ba055e21c76f456244b3b5109";
      sha256 = "147s1k4n45d3x281vj35l26sv4waxjlpqdn83z3k9n51556h1d45";
    };
    dependencies = [];

  };

  vim-addon-nix = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-nix-2017-09-11";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-nix";
      rev = "3001a9db5f816dd7af11384f15415bddd146ef86";
      sha256 = "195z2yz09wirpqjpsha8x7qcr9is1q8qph4j0svws6qbqrkh8ryy";
    };
    dependencies = ["vim-addon-completion" "vim-addon-goto-thing-at-cursor" "vim-addon-errorformats" "vim-addon-actions" "vim-addon-mw-utils" "tlib"];

  };

  vim-addon-other = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-other-2014-07-15";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-other";
      rev = "f78720c9cb5bf871cabb13c7cbf94378dbf0163b";
      sha256 = "0cjz7mlyfkkncas4ss7rwxb0q38ls1qw1p15hac1imscscsvyjc6";
    };
    dependencies = ["vim-addon-actions" "vim-addon-mw-utils"];

  };

  vim-addon-php-manual = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-php-manual-2015-01-01";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-php-manual";
      rev = "5f9810dd1f6e9f36a45f637ae6260ccff09256ff";
      sha256 = "1kc67f12wccqdza069b75lpcbqp4kv4r23i4mfz0ihwif5mfnhir";
    };
    dependencies = [];

  };

  vim-addon-signs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-signs-2013-04-19";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-signs";
      rev = "17a49f293d18174ff09d1bfff5ba86e8eee8e8ae";
      sha256 = "0i4gfp30hmw1vqjl6zxjrgkca3ikdkcnjmma2mncjmcr6f59kjzy";
    };
    dependencies = [];

  };

  vim-addon-sql = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-sql-2017-02-11";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-sql";
      rev = "048a139af36829fce670c8ff80d3aad927557ee6";
      sha256 = "0ihm157sby6csdwsnw2gwh3jmm3prm1mxwgkx2hsfwlmpb1vwwm3";
    };
    dependencies = ["vim-addon-completion" "vim-addon-background-cmd" "tlib"];

  };

  vim-addon-syntax-checker = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-syntax-checker-2017-06-26";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-syntax-checker";
      rev = "739e5719b77c6aea3299c27fc1f4238ac54a8344";
      sha256 = "1rcn1ps06156nyglvxg6m7pn3vhvmnv5ad6kidp59hggyr5332i9";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-toggle-buffer = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-toggle-buffer-2012-01-13";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-toggle-buffer";
      rev = "a1b38b9c5709cba666ed2d84ef06548f675c6b0b";
      sha256 = "1xq38kfdm36c34ln66znw841q797w5gm8bpq1x64bsf2h6n3ml03";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-xdebug = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-xdebug-2014-08-29";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-xdebug";
      rev = "45f26407305b4ce6f8f5f37d2b5e6e4354104172";
      sha256 = "1i64ppdfp2qqq7vw1jf160mj4ikc04v39iazdab83xmiqjsh8ixw";
    };
    dependencies = ["WebAPI" "vim-addon-mw-utils" "vim-addon-signs" "vim-addon-async"];

  };

  vim-airline = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-airline-2017-11-06";
    src = fetchgit {
      url = "git://github.com/vim-airline/vim-airline";
      rev = "396cc9226171f8dbf1069800a0ae56700bbf3913";
      sha256 = "1km9cvvrip5z8xzaa1r83n7w0kdw21zrxax27qmvnhlnq74s24zb";
    };
    dependencies = [];

  };

  vim-coffee-script = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-coffee-script-2017-03-03";
    src = fetchgit {
      url = "git://github.com/kchmck/vim-coffee-script";
      rev = "aace5c23d812a205c93e87ff79df72d9366928df";
      sha256 = "1saz5m3c329m2vk8ffhvxw4virz70k2qrjncwhvjpkik27jf75yy";
    };
    dependencies = [];

  };

  vim-easy-align = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easy-align-2017-06-03";
    src = fetchgit {
      url = "git://github.com/junegunn/vim-easy-align";
      rev = "1cd724dc239c3a0f7a12e0fac85945cc3dbe07b0";
      sha256 = "0bqk1sdqamfgagh31a60c7gvvsvjpg1xys7ivqh62iqlny5i9774";
    };
    dependencies = [];

  };

  vim-gista = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-gista-2017-02-20";
    src = fetchgit {
      url = "git://github.com/lambdalisue/vim-gista";
      rev = "b6cd41d0eb480cd79e84f3da3703613d0cf94a6c";
      sha256 = "0bkzbppd3jdci4yvifb4sh05q20qn8cr3j9kqhxyc703s0l0lk2s";
    };
    dependencies = [];

  };

  vim-gitgutter = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-gitgutter-2017-11-01";
    src = fetchgit {
      url = "git://github.com/airblade/vim-gitgutter";
      rev = "1e60667322b7cd1bfcba98762fbba746a888d21a";
      sha256 = "1g9giir7gmkp6n6w4z20qm2dyq00w2a8f573c0b8b27cj36ri0wq";
    };
    dependencies = [];

  };

  vim-iced-coffee-script = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-iced-coffee-script-2013-12-27";
    src = fetchgit {
      url = "git://github.com/noc7c9/vim-iced-coffee-script";
      rev = "e42e0775fa4b1f8840c55cd36ac3d1cedbc1dea2";
      sha256 = "14yfirny359rlrr082il2ys3hxiyrbbk794rdxrs2lasjy8rb1f7";
    };
    dependencies = [];

  };

  vim-latex-live-preview = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-latex-live-preview-2017-09-22";
    src = fetchgit {
      url = "git://github.com/xuhdev/vim-latex-live-preview";
      rev = "63abf0f2361e332597a5278b2dbd0fef980ebdb2";
      sha256 = "0pk2nx04bl8ym77mlylb6q5n3vz0y96jzs72gydjiffp1nm062l9";
    };
    dependencies = [];

  };

  vim-multiple-cursors = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-multiple-cursors-2017-08-04";
    src = fetchgit {
      url = "git://github.com/terryma/vim-multiple-cursors";
      rev = "a97dab5bc440bf0a7b62bb2de4479963a888f4ff";
      sha256 = "1ac5l5h138ns9z9ni4qbcykkg9yfpjjalk0g9wrra4rp0nlakaqk";
    };
    dependencies = [];

  };

  vim-signature = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-signature-2017-09-24";
    src = fetchgit {
      url = "git://github.com/kshenoy/vim-signature";
      rev = "eaa8af20ac4d46f911a083298d7a19e27be180e0";
      sha256 = "1vha52bmbs88lnwjfvkbx2jb74k8gqjky0c9gv8gqy74lypcdas5";
    };
    dependencies = [];

  };

  vim-signify = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-signify-2017-08-19";
    src = fetchgit {
      url = "git://github.com/mhinz/vim-signify";
      rev = "1a8a15d835d8f2da56cd793a0222227af6c89839";
      sha256 = "13yvwy2vw64g4v08k83svhp26nmmir0qd21wpp89qclbzwb2q2k2";
    };
    dependencies = [];

  };

  vim-snippets = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-snippets-2017-11-02";
    src = fetchgit {
      url = "git://github.com/honza/vim-snippets";
      rev = "a7670a7b71e44fd93e0b97fe2c24739a20732f94";
      sha256 = "0bm4475x723bk9q6snl5d804pn3vvsk0p9bvgil6c0q24ams6abh";
    };
    dependencies = [];

  };

  vim-webdevicons = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-webdevicons-2017-10-13";
    src = fetchgit {
      url = "git://github.com/ryanoasis/vim-devicons";
      rev = "a3e50225a8d544c9eff9c53c5405269a1b2b29f8";
      sha256 = "0glnwqnaw28g41zd9c3wvcsk6fmiphlwiq80lskbyn1pxfb3h14m";
    };
    dependencies = [];

  };

  vim2hs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim2hs-2014-04-16";
    src = fetchgit {
      url = "git://github.com/dag/vim2hs";
      rev = "f2afd55704bfe0a2d66e6b270d247e9b8a7b1664";
      sha256 = "18lqrl3hqb6cmizc04bbnsh8j0g761w2q8wascbzzfw80dmxy36b";
    };
    dependencies = [];

  };

  vimwiki = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimwiki-2017-11-04";
    src = fetchgit {
      url = "git://github.com/vimwiki/vimwiki";
      rev = "7c2ae8a714a71956297cb291dbaefb6a0ce47da3";
      sha256 = "1sis3g7v5ck9gan3x6i64kdfmn6r40zvxp2jyw0qxaha1kfb1qa1";
    };
    dependencies = [];

  };

  vinegar = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vinegar-2017-06-27";
    src = fetchgit {
      url = "git://github.com/tpope/vim-vinegar";
      rev = "c795cb739347cbddeeb288c3c35da9f140a513c9";
      sha256 = "1dcirb0b73s2l14ppn8mlh79pjpf9kgym9im05039ynr9rl83fv3";
    };
    dependencies = [];

  };

  vundle = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vundle-2017-06-08";
    src = fetchgit {
      url = "git://github.com/gmarik/vundle";
      rev = "6437ad6df4a3e6a87c5fb8bd2b8aadb277ec9c87";
      sha256 = "13k194g0rs5hz7ci0ys4gml71jily5hdd0yljzmmn8qjiq88v6p4";
    };
    dependencies = [];

  };
}
